==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/d2b/structTown.js <==
var structTown =
[
    [ "Town", "d5/d2b/structTown.html#a071df9ab6ef99a2860ec0f51bbceabb2", null ],
    [ "~Town", "d5/d2b/structTown.html#abd2ece7d9212bd32d12aae18c5dc6b4a", null ],
    [ "GetByTile", "d5/d2b/structTown.html#a538e050ddd905afa82543ad29d9ef41a", null ],
    [ "GetPercentTransported", "d5/d2b/structTown.html#a62682423019dbfe55c18acefaba97ab5", null ],
    [ "GetRandom", "d5/d2b/structTown.html#a5822a252b00a5dccc2678d123ddd0929", null ],
    [ "InitializeLayout", "d5/d2b/structTown.html#a89f39b3fc89841b3ab67524f2ab054dc", null ],
    [ "MaxTownNoise", "d5/d2b/structTown.html#a2c3721ce5f9fb38aa371e47780844743", null ],
    [ "PostDestructor", "d5/d2b/structTown.html#ad4d2b8026ade7a1d583c44f352a978fc", null ],
    [ "UpdateVirtCoord", "d5/d2b/structTown.html#a9e7b86387eddbe4bf1dba3962da1ca5b", null ],
    [ "cache", "d5/d2b/structTown.html#a7f35cfb2483debff60b8782f75a44c51", null ],
    [ "cargo_accepted", "d5/d2b/structTown.html#a1b0d9963c524ba2e261a6eee2ab73144", null ],
    [ "cargo_accepted_total", "d5/d2b/structTown.html#a06624a74e4159341116f04b35fa3a009", null ],
    [ "cargo_produced", "d5/d2b/structTown.html#a3ca52dc29760dda8b276a5c6f91cb5d9", null ],
    [ "exclusive_counter", "d5/d2b/structTown.html#acafb308862e09682861ed5839655b9e1", null ],
    [ "exclusivity", "d5/d2b/structTown.html#a88a45ce76b33822973a504db74e26a11", null ],
    [ "flags", "d5/d2b/structTown.html#a7d63c8c40090b9f968175eaa22801855", null ],
    [ "fund_buildings_months", "d5/d2b/structTown.html#a9c9f65d3706c084a1124c0039451810d", null ],
    [ "goal", "d5/d2b/structTown.html#aec3dbecf259262adf555ff15851e3572", null ],
    [ "grow_counter", "d5/d2b/structTown.html#a4644e09874762b194840ab88e13a82fc", null ],
    [ "growth_rate", "d5/d2b/structTown.html#a192d840c105bf297417fc51d3a31552b", null ],
    [ "have_ratings", "d5/d2b/structTown.html#ab22b8b339073f58d84d408fe452d8a45", null ],
    [ "larger_town", "d5/d2b/structTown.html#a062b400bc6ac0fd9d10a4e562ec04695", null ],
    [ "layout", "d5/d2b/structTown.html#a1c504c43941e48e03737a619dabee0a4", null ],
    [ "name", "d5/d2b/structTown.html#a3bacb694250905f314bdef3529b29aed", null ],
    [ "noise_reached", "d5/d2b/structTown.html#aae9aec67b65c511793c042e4c8a09b35", null ],
    [ "psa_list", "d5/d2b/structTown.html#a7d161596442bc2e1a57f7802b4e68747", null ],
    [ "ratings", "d5/d2b/structTown.html#a602f763590eb86d1b44f16013f854b24", null ],
    [ "received", "d5/d2b/structTown.html#a36edd764ff1a9b594a5c7a6c9f3d8ebe", null ],
    [ "road_build_months", "d5/d2b/structTown.html#a58b8cb8cada784d38266d32acd2751da", null ],
    [ "statues", "d5/d2b/structTown.html#a08b735b7cfb968c74e05f5870ea306fe", null ],
    [ "supplied", "d5/d2b/structTown.html#a51b6e519bab18ab07a53d469761f1b7b", null ],
    [ "text", "d5/d2b/structTown.html#a9372b35ab33f013ba435cd7577715b1e", null ],
    [ "time_until_rebuild", "d5/d2b/structTown.html#a2b9398ce8bb88f391420577f78de7589", null ],
    [ "townnamegrfid", "d5/d2b/structTown.html#a01df11ccdbf8a4babe555e464b5a411e", null ],
    [ "townnameparts", "d5/d2b/structTown.html#a4ab960f4f94918033f826b168a4ba3d2", null ],
    [ "townnametype", "d5/d2b/structTown.html#a9235723afd165be851676b78fcf9b73d", null ],
    [ "unwanted", "d5/d2b/structTown.html#a4615b1456ee8d73cd4e7716363f55f26", null ],
    [ "xy", "d5/d2b/structTown.html#a1e5c4bd069ae3342fd36140d9187f267", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/d2b/structTown.js <==
var structTown =
[
    [ "Town", "d5/d2b/structTown.html#a071df9ab6ef99a2860ec0f51bbceabb2", null ],
    [ "~Town", "d5/d2b/structTown.html#abd2ece7d9212bd32d12aae18c5dc6b4a", null ],
    [ "FillCachedName", "d5/d2b/structTown.html#a1e1c6b87cb2cc01e099860db2b0ec4dc", null ],
    [ "GetByTile", "d5/d2b/structTown.html#a538e050ddd905afa82543ad29d9ef41a", null ],
    [ "GetCachedName", "d5/d2b/structTown.html#ab6a0c2a3e8402d393b64b603964fd4bd", null ],
    [ "GetPercentTransported", "d5/d2b/structTown.html#a62682423019dbfe55c18acefaba97ab5", null ],
    [ "GetRandom", "d5/d2b/structTown.html#a5822a252b00a5dccc2678d123ddd0929", null ],
    [ "InitializeLayout", "d5/d2b/structTown.html#a89f39b3fc89841b3ab67524f2ab054dc", null ],
    [ "MaxTownNoise", "d5/d2b/structTown.html#a2c3721ce5f9fb38aa371e47780844743", null ],
    [ "PostDestructor", "d5/d2b/structTown.html#ad4d2b8026ade7a1d583c44f352a978fc", null ],
    [ "UpdateVirtCoord", "d5/d2b/structTown.html#a9e7b86387eddbe4bf1dba3962da1ca5b", null ],
    [ "cache", "d5/d2b/structTown.html#a7f35cfb2483debff60b8782f75a44c51", null ],
    [ "cached_name", "d5/d2b/structTown.html#a15d2873579c13a44e41f8f0c650e5755", null ],
    [ "exclusive_counter", "d5/d2b/structTown.html#acafb308862e09682861ed5839655b9e1", null ],
    [ "exclusivity", "d5/d2b/structTown.html#a82c102924c9738c3273996a8fb18cfef", null ],
    [ "flags", "d5/d2b/structTown.html#a7d63c8c40090b9f968175eaa22801855", null ],
    [ "fund_buildings_months", "d5/d2b/structTown.html#a9c9f65d3706c084a1124c0039451810d", null ],
    [ "goal", "d5/d2b/structTown.html#aec3dbecf259262adf555ff15851e3572", null ],
    [ "grow_counter", "d5/d2b/structTown.html#a4644e09874762b194840ab88e13a82fc", null ],
    [ "growth_rate", "d5/d2b/structTown.html#a192d840c105bf297417fc51d3a31552b", null ],
    [ "have_ratings", "d5/d2b/structTown.html#ab22b8b339073f58d84d408fe452d8a45", null ],
    [ "larger_town", "d5/d2b/structTown.html#a062b400bc6ac0fd9d10a4e562ec04695", null ],
    [ "layout", "d5/d2b/structTown.html#a3a40ba76415e4912cd8c18eed0a8a875", null ],
    [ "name", "d5/d2b/structTown.html#a5c7aebc6b1c6eade8a853d8d6ee57b3b", null ],
    [ "noise_reached", "d5/d2b/structTown.html#aae9aec67b65c511793c042e4c8a09b35", null ],
    [ "psa_list", "d5/d2b/structTown.html#a7d161596442bc2e1a57f7802b4e68747", null ],
    [ "ratings", "d5/d2b/structTown.html#a602f763590eb86d1b44f16013f854b24", null ],
    [ "received", "d5/d2b/structTown.html#a36edd764ff1a9b594a5c7a6c9f3d8ebe", null ],
    [ "road_build_months", "d5/d2b/structTown.html#a58b8cb8cada784d38266d32acd2751da", null ],
    [ "show_zone", "d5/d2b/structTown.html#a923a9963a92eeed4503bfc43ac568fa2", null ],
    [ "stations_near", "d5/d2b/structTown.html#ad46327607edfdbe8acf7de1aecfeba38", null ],
    [ "statues", "d5/d2b/structTown.html#a08b735b7cfb968c74e05f5870ea306fe", null ],
    [ "supplied", "d5/d2b/structTown.html#a51b6e519bab18ab07a53d469761f1b7b", null ],
    [ "text", "d5/d2b/structTown.html#aae0e438fd91e3c0abdd0767585a2d0c2", null ],
    [ "time_until_rebuild", "d5/d2b/structTown.html#a2b9398ce8bb88f391420577f78de7589", null ],
    [ "townnamegrfid", "d5/d2b/structTown.html#a01df11ccdbf8a4babe555e464b5a411e", null ],
    [ "townnameparts", "d5/d2b/structTown.html#a4ab960f4f94918033f826b168a4ba3d2", null ],
    [ "townnametype", "d5/d2b/structTown.html#a9235723afd165be851676b78fcf9b73d", null ],
    [ "unwanted", "d5/d2b/structTown.html#a4615b1456ee8d73cd4e7716363f55f26", null ],
    [ "xy", "d5/d2b/structTown.html#a1e5c4bd069ae3342fd36140d9187f267", null ]
];
